searchData={"items":[{"type":"module","title":"VintageNetQMI","doc":"Use a QMI-enabled cellular modem with VintageNet\n\nThis module is not intended to be called directly but via calls to `VintageNet`. Here's an\nexample:\n\n```elixir\nVintageNet.configure(\n  \"wwan0\",\n  %{\n    type: VintageNetQMI,\n    vintage_net_qmi: %{\n      service_providers: [\n        %{apn: \"favorite_apn\", only_iccid_prefixes: [\"1234\"]},\n        %{apn: \"second_favorite_apn\", only_iccid_prefixes: [\"56789\"]},\n        %{apn: \"last_resort_apn\"}\n      ],\n      only_radio_technologies: [:lte]\n    }\n  }\n)\n```\n\nThe following keys are supported\n\n* `:service_providers` - This is a list of service provider information\n\nThe `:service_providers` key should be set to information provided by each of\nyour service providers.\n\nInformation for each service provider is a map with some or all of the following\nfields:\n\n* `:apn` (required) - e.g., `\"access_point_name\"`\n* `:only_iccid_prefixes` (optional) - only use this APN if the one of the strings\n  in the list is a prefix of the ICCID. E.g, `[\"1234\"]`\n\nWhen multiple entries are specified, the first allowed service provider is used.\n\nYour service provider should provide you with the information that you need to\nconnect. Often it is just an APN. The Gnome project provides a database of\n[service provider\ninformation](https://wiki.gnome.org/Projects/NetworkManager/MobileBroadband/ServiceProviders)\nthat may also be useful.","ref":"VintageNetQMI.html"},{"type":"function","title":"VintageNetQMI.qmi_name/1","doc":"Name of the the QMI server that VintageNetQMI uses","ref":"VintageNetQMI.html#qmi_name/1"},{"type":"function","title":"VintageNetQMI.quick_configure/1","doc":"Configure a cellular modem using an APN\n\n```\niex> VintageNetQMI.quick_configure(\"an_apn\")\n:ok\n```","ref":"VintageNetQMI.html#quick_configure/1"},{"type":"module","title":"VintageNetQMI.ASUCalculator","doc":"Convert raw ASU values to friendlier units\n\nSee https://en.wikipedia.org/wiki/Mobile_phone_signal#ASU for\nmore information.\n\nThe following conversions are done:\n\n* dBm\n* Number of \"bars\" out of 4 bars","ref":"VintageNetQMI.ASUCalculator.html"},{"type":"function","title":"VintageNetQMI.ASUCalculator.from_gsm_asu/1","doc":"Compute signal level numbers from a GSM ASU\n\nThe `AT+CSQ` command should report ASU values in this format.","ref":"VintageNetQMI.ASUCalculator.html#from_gsm_asu/1"},{"type":"function","title":"VintageNetQMI.ASUCalculator.from_lte_rssi/1","doc":"","ref":"VintageNetQMI.ASUCalculator.html#from_lte_rssi/1"},{"type":"type","title":"VintageNetQMI.ASUCalculator.bars/0","doc":"Number of bars out of 4 to show in a UI","ref":"VintageNetQMI.ASUCalculator.html#t:bars/0"},{"type":"type","title":"VintageNetQMI.ASUCalculator.dbm/0","doc":"dBm","ref":"VintageNetQMI.ASUCalculator.html#t:dbm/0"},{"type":"type","title":"VintageNetQMI.ASUCalculator.gsm_asu/0","doc":"GSM ASU values\n\nASU values map to RSSI. 99 means unknown","ref":"VintageNetQMI.ASUCalculator.html#t:gsm_asu/0"},{"type":"type","title":"VintageNetQMI.ASUCalculator.lte_asu/0","doc":"LTE ASU values\n\nASU values map to RSRP\n\nhttps://arimas.com/78-rsrp-and-rsrq-measurement-in-lte/","ref":"VintageNetQMI.ASUCalculator.html#t:lte_asu/0"},{"type":"type","title":"VintageNetQMI.ASUCalculator.umts_asu/0","doc":"UMTS ASU values\n\nASU values map to RSCP","ref":"VintageNetQMI.ASUCalculator.html#t:umts_asu/0"},{"type":"module","title":"VintageNetQMI.Connection","doc":"Establish an connection with the QMI device","ref":"VintageNetQMI.Connection.html"},{"type":"function","title":"VintageNetQMI.Connection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"VintageNetQMI.Connection.html#child_spec/1"},{"type":"function","title":"VintageNetQMI.Connection.process_stats/2","doc":"Process connection stats\n\nThis will post the updated stats as properties.","ref":"VintageNetQMI.Connection.html#process_stats/2"},{"type":"function","title":"VintageNetQMI.Connection.start_link/1","doc":"Start the Connection server","ref":"VintageNetQMI.Connection.html#start_link/1"},{"type":"type","title":"VintageNetQMI.Connection.arg/0","doc":"Options for to establish the connection\n\n`:apn` - The Access Point Name of the service provider","ref":"VintageNetQMI.Connection.html#t:arg/0"},{"type":"module","title":"VintageNetQMI.Cookbook","doc":"Recipes for common QMI network configurations","ref":"VintageNetQMI.Cookbook.html"},{"type":"function","title":"VintageNetQMI.Cookbook.simple/1","doc":"Return a configuration for connecting to a cellular network by APN","ref":"VintageNetQMI.Cookbook.html#simple/1"},{"type":"module","title":"VintageNetQMI.MCCMNC","doc":"MCC/MNC database lookups\n\nThis database uses data from https://s3.amazonaws.com/mcc-mnc.net/mcc-mnc.csv.\nMCC-MNC.net is licensed under the MIT Open Source license.","ref":"VintageNetQMI.MCCMNC.html"},{"type":"function","title":"VintageNetQMI.MCCMNC.lookup_brand/2","doc":"Look up the specified MCC/MNC and return the service provider's brand name","ref":"VintageNetQMI.MCCMNC.html#lookup_brand/2"},{"type":"function","title":"Examples - VintageNetQMI.MCCMNC.lookup_brand/2","doc":"iex> VintageNetQMI.MCCMNC.lookup_brand(\"310\", \"410\")\n    \"AT&T\"","ref":"VintageNetQMI.MCCMNC.html#lookup_brand/2-examples"},{"type":"extras","title":"VintageNetQMI","doc":"# VintageNetQMI\n\n[![Hex version](https://img.shields.io/hexpm/v/vintage_net_qmi.svg \"Hex version\")](https://hex.pm/packages/vintage_net_qmi)\n[![API docs](https://img.shields.io/hexpm/v/vintage_net_qmi.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/vintage_net_qmi/VintageNetQMI.html)\n[![CircleCI](https://circleci.com/gh/nerves-networking/vintage_net_qmi.svg?style=svg)](https://circleci.com/gh/nerves-networking/vintage_net_qmi)\n\nThis library provides a `VintageNet` technology for cellular modems that\nsupport the Qualcomm MSM Interface. This includes most USB cellular modems.\nSee [`VintageNetMobile`](https://github.com/nerves-networking/vintage_net_mobile)\nif you have a modem that only supports an `AT` command interface.\n\nTo use this library, first add it to your project's dependency list:\n\n```elixir\ndef deps do\n  [\n    {:vintage_net_qmi, \"~> 0.3.2\"}\n  ]\nend\n```\n\nYou will then need to configure `VintageNet`. The easiest way to configure\na modem at runtime is by calling `VintageNetQMI.quick_configure(\"the_apn\")`.\nFor example:\n\n```elixir\niex> VintageNetQMI.quick_configure(\"the_apn\")\n:ok\n# wait...\niex> VintageNet.info\nInterface wwan0\n  Type: VintageNetQMI\n  Power: On (watchdog timeout in 51628 ms)\n  Present: true\n  State: :configured (0:41:09)\n  Connection: :internet (0:40:28)\n  Addresses: 100.79.205.206/30, fe80::723c:bdc9:10e4:d092/64\n  Configuration:\n    %{\n      type: VintageNetQMI,\n      vintage_net_qmi: %{service_providers: [%{apn: \"the_apn\"}]}\n    }\n```\n\nYou can't always call `quick_configure/1` convenience function so here's the\nregular configuration. If you are moving code from `vintage_net_mobile`, you'll\nnotice that this format is very similar except that `Mobile` is now `QMI`.\n\n```elixir\nVintageNet.configure(\"wwan0\", %{\n      type: VintageNetQMI,\n      vintage_net_qmi: %{\n        service_providers: [%{apn: \"the_apn\"}]\n      }\n    })\n```\n\nThe `:service_providers` key should be set to information provided by each of\nyour service providers. It is common that this is a list of one item.\nCurrently only one service provider is supported, so replace `\"fill_in\"` with\nthe APN that they gave you.","ref":"readme.html"},{"type":"extras","title":"Service provider APN selection via ICCID - VintageNetQMI","doc":"If you're deploying SIMs from multiple service providers, you'll need to set\nthe APN based on what SIM was installed in the device. One way is to set\na configuration manually when you install the SIM. An easier way is to have\n`VintageNetQMI` pick the APN based on the SIM's ICCID.\n\nThis featured is enabled by using the `:only_iccid_prefixes` option and listing\nmultiple service providers. `VintageNetQMI` looks at the `:service_providers`\nlist in order until one matches. Leave off the`:only_iccid_prefixes` option on\nthe final service provider to provide a catch-all APN.\n\nHere's an example:\n\n```elixir\nVintageNet.configure(\"wwan0\", %{\n      type: VintageNetQMI,\n      vintage_net_qmi: %{\n        service_providers: [\n          %{apn: \"special_service_provider\", only_iccid_prefixes: [\"8973611\", \"8973612\"]},\n          %{apn: \"default_apn\"}\n        ]\n      }\n    })\n```","ref":"readme.html#service-provider-apn-selection-via-iccid"},{"type":"extras","title":"Configure radio technologies - VintageNetQMI","doc":"In some cases you might want to set to the radio access technology (RAT) to only\nuse a subset of what the modem is capable of using. To specify which RATs to use\nyou can set the optional configuration field `:only_radio_technologies`.\n\n```elixir\nVintageNet.configure(\"wwan0\", %{\n      type: VintageNetQMI,\n      vintage_net_qmi: %{\n        only_radio_technologies: [:lte, :umts],\n        service_providers: [\n          %{apn: \"apn_name\"}\n        ]\n      }\n    })\n```\n\nThe example above will limit the possible RATs used to `:lte` (4G) and `:umts`\n(3G). For more information which radio technologies are available please see\nthe `:qmi` [documentation](https://hexdocs.pm/qmi/QMI.Codec.NetworkAccess.html#t:radio_interface/0).\n\nIf this configuration is provided, the modem will use the default configuration\nthat provided by the manufacturer.","ref":"readme.html#configure-radio-technologies"},{"type":"extras","title":"Configure roaming - VintageNetQMI","doc":"Support for allowing roaming is set on a per-service provider basis using\nthe `:roaming_allowed?` key. In QMI, this field is optional and if unset here,\nVintageNetQMI will not send any preference to the modem. The following\nexample shows a configuration where roaming is allowed:\n\n```elixir\nVintageNet.configure(\"wwan0\", %{\n      type: VintageNetQMI,\n      vintage_net_qmi: %{\n        only_radio_technologies: [:lte, :umts],\n        service_providers: [\n          %{apn: \"apn_name\", roaming_allowed?: true}\n        ]\n      }\n    })\n```","ref":"readme.html#configure-roaming"},{"type":"extras","title":"VintageNet Properties - VintageNetQMI","doc":"In addition to the common `vintage_net` properties for all interface types, this\ntechnology the following:\n\n| Property      | Values         | Description                   |\n| ------------- | -------------- | ----------------------------- |\n| `signal_asu`  | `0-31,99`      | Reported Arbitrary Strength Unit (ASU) |\n| `signal_4bars` | `0-4`         | The signal level in \"bars\"    |\n| `signal_dbm`  | `-144 - -44`   | The signal level in dBm. Interpretation depends on the connection technology. |\n| `mcc`         | `0-999` | `nil`| Mobile Country Code for the network |\n| `mnc`         | `0-999` | `nil`| Mobile Network Code for the network |\n| `iccid`       | string         | The Integrated Circuit Card Identifier (ICCID) |\n| `esn`         | string         | The Electronic Serial Number (ESN) |\n| `imei`        | string         | International Mobile Equipment Identity (IMEI) |\n| `meid`        | string         | The Mobile Equipment Identifier (MEID) |\n| `imeisv_svn`  | string         | IMEI software version number |\n| `provider`    | string | `nil` | The name of the service provider |\n| `lac`         | `0-65533`      | The Location Area Code (lac) for the current cell |\n| `cid`         | `0-268435455`  | The Cell ID (cid) for the current cell |\n| `network_datetime` | `NaiveDateTime.t()` | The reported datetime from the network |\n| `utc_offset`  | `Calendar.utc_offset()` | The UTC offset in seconds |\n| `roaming`     | `boolean()`    | If the network is roaming or not |\n| `std_offset`  | `Calendar.std_offset()` | The standard offset in seconds |\n| `statistics`  | map            | Transmit and receive statistics (see below for details) |\n| `access_technology` | atom     | The technology currently in use to connect to the network |\n| `band`        | string         | The frequency band in use |\n| `channel`     | integer        | An integer that indicates the channel that's in use |\n| `manufacturer` | string        | The name of the manufacturer of the modem |\n| `model`       | string         | The name of the model of the modem        |\n| `apn`         | string         | The APN that VintageNetQMI configured the modem to use |\n| `sim_rej_info`| atom           | The reason (if any) a SIM was rejected |\n\nThe following properties are TBD:\n\n| Property      | Values         | Description                   |\n| ------------- | -------------- | ----------------------------- |\n| `imsi`        | string         | The International Mobile Subscriber Identity (IMSI) |","ref":"readme.html#vintagenet-properties"},{"type":"extras","title":"Transmit and receive statistics - VintageNetQMI","doc":"The `statistics` value is a map with the fields:\n\n* `:timestamp` - the monotonic time for when these stats where last updated\n* `:tx_bytes` - total bytes transmitted\n* `:rx_bytes` - total bytes received\n* `:tx_packets` - total packets transmitted without error\n* `:rx_packets` - total packets received without error\n* `:tx_errors` - total outgoing packets with framing errors\n* `:rx_errors` - total incoming packets with framing errors\n* `:tx_overflows` - total outing packets dropped due to buffer overflows\n* `:rx_overflows` - total incoming packets dropped due to buffer overflows\n* `:tx_drops` - total outgoing packets dropped\n* `:rx_drops` - total incoming packets dropped","ref":"readme.html#transmit-and-receive-statistics"},{"type":"extras","title":"Types of radio access technologies - VintageNetQMI","doc":"* `:amps` - Advanced Mobile Phone System (legacy)\n* `:gsm` - Global System for Mobile Communication (3G & 2G)\n* `:umts` - Universal Mobile Telecommunications System (3G)\n* `:lte` - Long-Term Evolution (4G)\n* `:cdma_1x` - CDMA2000 1X (3G & 2G)\n* `:cdma_1x_evdo` - CDMA2000 1xEV-DO (3G & 2G)\n\nIf you migrating from `VintageNetMobile` you will need to update any code that\nuses this property to handle the above list of atoms.","ref":"readme.html#types-of-radio-access-technologies"},{"type":"extras","title":"System requirements - VintageNetQMI","doc":"These requirements are believed to be the minimum needed to be added to the\nofficial Nerves systems.","ref":"readme.html#system-requirements"},{"type":"extras","title":"Linux kernel - VintageNetQMI","doc":"Enable QMI and drivers for your modem:\n\n```text\nCONFIG_USB_USBNET=m\nCONFIG_USB_NET_CDC_NCM=m\nCONFIG_USB_NET_QMI_WWAN=m\nCONFIG_USB_SERIAL_OPTION=m\n```\n\nIf you're using a Huawei modem, you might also want:\n\n```text\nCONFIG_USB_NET_HUAWEI_CDC_NCM=m\n```","ref":"readme.html#linux-kernel"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [v0.4.2] - 2024-08-30","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"* `sim_rej_info` has been added to the PropertyTable.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"* PropertyTable properties have been updated to not contain invalid characters\n  * MNC\n  * MCC\n* `provider` PropertyTable property Will now work correctly with updated MNC/MCC properties.\n\n## [v0.4.1] - 2024-08-06","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Fix various ways that a cellular module with trouble reading a SIM card could\n  cause a crash. This was a low probability event that actually accumulated a\n  lot of crash reports.\n* Reduce retry rate for SIM card read errors from 1s to 5s. These are unlikely\n  to recover and retrying every second logged a lot.\n\n## [v0.4.0] - 2024-07-25","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Require Elixir 1.14 and OTP 25. This was done to support more convenient\n  binary patterns in the QMI library.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* Determine the cellular provider a different way that works reliably with\n  multi-network SIM cards. This adds a small database to look up the provider\n  based on MCC and MNC.\n\n## [v0.3.6] - 2023-05-16","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"* Don't crash when selecting the APN when the ICCID is `nil`. This is an error\n  case that's made more confusing by this exception. The default APN will be\n  selected even though it's probably futile.\n\n## [v0.3.5] - 2023-04-25","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Restrict reported ASU values to 0-31 | 99 to match expected values.  In one\n  case, 32 was reported for a strong signal, but prior to the change there\n  wasn't a limit.\n\n## [v0.3.4] - 2023-03-23","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Add grace period on serving system disconnects since they're often followed\n  very quickly by a reconnect when moving between cell towers. This\n  fixes an issue where TCP connections would unnecessarily be terminated and\n  only to reconnect a second later.\n\n## [v0.3.3] - 2023-01-23","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Allow `:vintage_net` `v0.13.0` to be used\n* Add some more information when QMI reports no internet\n\n## [v0.3.2] - 2022-05-02","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* `:vintage_net` `v0.12.0` and up is now required\n\n## [v0.3.1] - 2022-04-27","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* Add support for `:roaming_allowed?` field in a service provider configuration\n  to allow or disallow roaming when using the configured service provider.\n\n## [v0.3.0] - 2022-02-10\n\nThere was a fix that changed the property reported in the property table from\n`\"manufacture\"` to `\"manufacturer\"`. To upgrade you will want to change any\ncode that this is subscribe to this property to have the correct spelling.","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* Add support to configure which radio technologies you want the modem to use","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Changelog","doc":"* References to manufacturer\n* Infinite retrying to establish connection after the connection has been\n  established\n* Report selected APN before connection attempt\n\n## [v0.2.14] - 2022-1-13","ref":"changelog.html#fixes"},{"type":"extras","title":"Added - Changelog","doc":"* Show the configured APN in the property table\n\n## [v0.2.13] - 2022-1-4","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* Allow APN selection based off ICCID when deploying SIMs from multiple service\n  providers\n\n## [v0.2.12] - 2021-12-20","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"* Property named `\"manufacturer\"` for the manufacturer name of the modem\n* Property named `\"model\"` for the product name of the modem\n\n## [v0.2.11] - 2021-11-18","ref":"changelog.html#added"},{"type":"extras","title":"Fixes - Changelog","doc":"- When there is no signal VintageNetQMI would report 1 bar of signal rather than\n  0 bars\n\n## [v0.2.10] - 2021-11-17","ref":"changelog.html#fixes"},{"type":"extras","title":"Changes - Changelog","doc":"- Power manager timer was petting the watch dog every 60 miliseconds, now it\n  will pet the watch dog every 30 seconds.\n- Ignore sync indications from QMI so they are not logged.","ref":"changelog.html#changes"},{"type":"extras","title":"Fixes - Changelog","doc":"- A crash that happened when the interface would stop but there was no IP\n  address on the interface.\n- Internet connectivity checker being enabled when it should not have been\n\n## [v0.2.9] - 2021-09-21","ref":"changelog.html#fixes"},{"type":"extras","title":"Added - Changelog","doc":"* Property named `\"statistics\"` that contains a map of transmit and receive\n  stats. The fields are:\n  * `:timestamp` - monotonic time for when the stats were last updated\n  * `:tx_bytes` - total bytes transmitted\n  * `:rx_bytes` - total bytes received\n  * `:tx_packets` - total packets transmitted without error\n  * `:rx_packets` - total packets received without error\n  * `:tx_errors` - total outgoing packets with framing errors\n  * `:rx_errors` - total incoming packets with framing errors\n  * `:tx_overflows` - total outing packets dropped due to buffer overflows\n  * `:rx_overflows` - total incoming packets dropped due to buffer overflows\n  * `:tx_drops` - total outgoing packets dropped\n  * `:rx_drops` - total incoming packets dropped\n* Property `\"band\"` for the frequency band being used by the radio interface\n* Property `\"channel\"` for the channel being used by the radio interface\n* Property `\"access_technology\"` for the radio interface that is active","ref":"changelog.html#added"},{"type":"extras","title":"v0.2.8 - Changelog","doc":"* Added\n  * Location and time properties:\n    * `lac` - The Location Area Code (lac) for the current cell\n    * `cid` - The Cell ID (cid) for the current cell\n    * `network_datetime` - The reported datetime from the network\n    * `utc_offset` - The UTC offset in seconds\n    * `roaming` - If the network is roaming or not\n    * `std_offset` - The standard offset in seconds","ref":"changelog.html#v0-2-8"},{"type":"extras","title":"v0.2.7 - Changelog","doc":"* Added\n  * Support `VintageNet` v0.11.x\n  * Serial number properties:\n    * `esn` - Electronic Serial Number (ESN)\n    * `imei` - International Mobile Equipment Identity (IMEI)\n    * `meid` - Mobile Equipment Identifier (MEID)\n    * `imeisv_svn` - IMEI software version number\n  * The `provider` property to get the service provider name\n\n* Fixes\n  * When packet data connection is disconnected set the connection status to\n    `:disconnected`\n  * Check connectivity status to know if the modem should power cycle","ref":"changelog.html#v0-2-7"},{"type":"extras","title":"v0.2.6 - Changelog","doc":"* Fixes\n  * Fix lease renewal ending in stuck lan connectivity","ref":"changelog.html#v0-2-6"},{"type":"extras","title":"v0.2.5 - Changelog","doc":"* Updates\n  * Support `qmi` v0.6.0","ref":"changelog.html#v0-2-5"},{"type":"extras","title":"v0.2.4 - Changelog","doc":"* Improvements\n  * Support `iccid` property\n\n* Updates\n  * Support `qmi` v0.5.1","ref":"changelog.html#v0-2-4"},{"type":"extras","title":"v0.2.3 - Changelog","doc":"* Fixes\n  * `VintageNetQMI.quick_configure/1` updated to use the passed in argument\n    for the APN instead of always using hardcoded `\"apn\"` value","ref":"changelog.html#v0-2-3"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* Improvements\n  * Add `VintageNetQMI.quick_configure/1` to easily configure `VintageNet` at\n    runtime.\n\n* Updates\n  * Support `vintage_net` v0.10.2\n  * Better handling of connection status","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"* Updates\n  * Set connection based on QMI notifications","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* Updates\n  * Change configuration to match VintageNetMobile (backwards incompatible)\n  * Don't require IPv4 configuration","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.3 - Changelog","doc":"* Updates\n  * Support `qmi` v0.3.1\n\n* Fixes\n  * Connection code blocking supervision initialization","ref":"changelog.html#v0-1-3"},{"type":"extras","title":"v0.1.2 - Changelog","doc":"* Updates\n  * Support `qmi` v0.2.0","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Updates\n  * Support vintage_net v0.10.0","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial Release\n\n[v0.4.1]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.4.0...v0.4.1\n[v0.4.0]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.6...v0.4.0\n[v0.3.6]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.5...v0.3.6\n[v0.3.5]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.4...v0.3.5\n[v0.3.4]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.3...v0.3.4\n[v0.3.3]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.2...v0.3.3\n[v0.3.2]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.1...v0.3.2\n[v0.3.1]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.3.0...v0.3.1\n[v0.3.0]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.14...v0.3.0\n[v0.2.14]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.13...v0.2.14\n[v0.2.13]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.12...v0.2.13\n[v0.2.12]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.11...v0.2.12\n[v0.2.11]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.10...v0.2.11\n[v0.2.10]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.9...v0.2.10\n[v0.2.9]: https://github.com/nerves-networking/vintage_net_qmi/compare/v0.2.8...v0.2.9","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}